@@ -57,7 +57,9 @@ def watch(fns, path, files=None, run_immediately=True, recursive=False, throttle
                     f['path'] = path
 
     f = get_files(files) if files else None
-    handler = handler or WatchHandler(fns, throttle=throttle, predicate=lambda event: not f or event.src_path in f)
+    handler = handler or WatchHandler(fns, 
+            throttle=throttle, 
+            predicate=lambda event: not f or event.src_path in f)
 
     observer = Observer()
     observer.schedule(
@@ -116,24 +118,9 @@ class WatchHandler(FileSystemEventHandler):
                 logger.info("Throttle time not elapsed - not running event")
                 return
 
-        if not self.last_run:
-            self.last_run = datetime.datetime.now()
+        self.last_run = datetime.datetime.now()
 
         try:
-            def predicate(fn):
-                """
-                This predicate will determine if a function should run in the watch based on
-                if the task files were modified for that function.
-                :param fn: the functions to see if we should run
-                :return: True if the function should run.
-                """
-                if isinstance(fn, dict) and fn.get('kwargs') and 'files' in fn['kwargs']:
-                    return event.src_path in get_files(fn['kwargs']['files'])
-                elif callable(fn) and fn.keywords and 'files' in fn.keywords:
-                    return event.src_path in get_files(fn.keywords.files)
-
-                return False
-
             run_function_list(self.fns)
             if self.callback:
                 self.callback(event, self.fns)
